@@ -20,6 +20,9 @@ import re
 import boto3
 import requests
 
+from . import CLIENT_VERSION
+from .util import throw_if_bad_response
+
 class AWSAuth(object):
     """Class to authenticate with an IAM Role"""
     cerberus_url = None
@@ -27,11 +30,13 @@ class AWSAuth(object):
     region = None
     assume_role = False
 
-    def __init__(self, cerberus_url, role_arn=None, region=None):
-        self.cerberus_url = cerberus_url
-        self.set_auth(role_arn, region)
+    HEADERS = {"Content-Type": "application/json", "X-Cerberus-Client": "CerberusPythonClient/" + CLIENT_VERSION}
 
-    def set_auth(self, role_arn=None, region=None):
+    def __init__(self, cerberus_url, role_arn=None, region=None, assume_role=True):
+        self.cerberus_url = cerberus_url
+        self.set_auth(role_arn, region, assume_role)
+
+    def set_auth(self, role_arn=None, region=None, assume_role=True):
         """Sets the variables needed for AWS Auth"""
         sts_client = boto3.client('sts')
 
@@ -53,7 +58,7 @@ class AWSAuth(object):
                     else "arn:aws:iam::" + account_id + ":role/" + role_with_path
         else:
             self.role_arn = role_arn
-            self.assume_role = True
+            self.assume_role = assume_role
 
         if region is None:
             self.region = self.get_region()
@@ -107,10 +112,11 @@ class AWSAuth(object):
             'iam_principal_arn': self.role_arn,
             'region': self.region
         }
-        encrypted_resp = requests.post(self.cerberus_url + '/v2/auth/iam-principal', data=json.dumps(request_body))
+        encrypted_resp = requests.post(self.cerberus_url + '/v2/auth/iam-principal', data=json.dumps(request_body),
+                                       headers=self.HEADERS)
 
         if encrypted_resp.status_code != 200:
-            encrypted_resp.raise_for_status()
+            throw_if_bad_response(encrypted_resp)
 
         auth_data = encrypted_resp.json()['auth_data']
         if not self.assume_role:
